@@ -51,7 +51,7 @@ Eigen::MatrixXd Rmullwlsk( const Eigen::Map<Eigen::VectorXd> & bw, const std::st
   
   Eigen::MatrixXd mu(ygrid.size(),xgrid.size());
   mu.setZero();    
-  double bufSmall =  pow(double(10),-6);
+  const double bufSmall = 1.0e-6; // pow(double(10),-6);
 
   for (unsigned int i = 0; i != ygridN; ++i){  
     for (unsigned int j = i; j < xgridN ; ++j){ 
@@ -139,11 +139,10 @@ Eigen::MatrixXd Rmullwlsk( const Eigen::Map<Eigen::VectorXd> & bw, const std::st
         X.setOnes();    
         X.col(1) = lx.row(0).array() - xgrid(j);
         X.col(2) = lx.row(1).array() - ygrid(i); 
-        Eigen::LLT<Eigen::MatrixXd> llt_XTWX(X.transpose() * temp.asDiagonal() *X);
-        // Probably change LLT to LDLT for increased numerical stability.
+        Eigen::LDLT<Eigen::MatrixXd> ldlt_XTWX(X.transpose() * temp.asDiagonal() *X);
         // The solver should stop if the value is NaN. See the HOLE example in gcvlwls2dV2.
-        Eigen::VectorXd beta = llt_XTWX.solve(X.transpose() * temp.asDiagonal() * ly);
-        mu(i,j)=beta(0); 
+        Eigen::VectorXd beta = ldlt_XTWX.solve(X.transpose() * temp.asDiagonal() * ly);
+        mu(i,j)=beta(0);  
       } else if(meter < 3){
         // Rcpp::Rcout <<"The meter value is:" << meter << std::endl;  
         if (bwCheck) {
